@@ -11,14 +11,15 @@ context=article
     http://www.lume.ufrgs.br/handle/10183/26950
 """
 
+from colour.utilities import LazyCanonicalMapping
+
 from .crt import MSDS_DISPLAY_PRIMARIES_CRT
 from .lcd import MSDS_DISPLAY_PRIMARIES_LCD
-from colour.utilities import LazyCanonicalMapping
 
 MSDS_DISPLAY_PRIMARIES = LazyCanonicalMapping(MSDS_DISPLAY_PRIMARIES_CRT)
 MSDS_DISPLAY_PRIMARIES.update(MSDS_DISPLAY_PRIMARIES_LCD)
 MSDS_DISPLAY_PRIMARIES.__doc__ = """
-Primaries multi-spectral distributions of displays.
+Multi-spectral distributions of display primaries.
 
 References
 ----------
@@ -26,5 +27,8 @@ References
 """
 
 __all__ = [
-    "MSDS_DISPLAY_PRIMARIES",
+    "MSDS_DISPLAY_PRIMARIES_CRT",
+]
+__all__ += [
+    "MSDS_DISPLAY_PRIMARIES_LCD",
 ]
