@@ -1,11 +1,17 @@
-"""Showcase *Hellwig and Fairchild (2022)* colour appearance model computations."""
+"""
+Demonstrate *Hellwig and Fairchild (2022)* colour appearance model computations.
+
+This module provides examples of colour appearance model computations using the
+*Hellwig and Fairchild (2022)* model, illustrating both forward and inverse
+transformations between tristimulus values and colour appearance correlates.
+"""
 
 import numpy as np
 
 import colour
 from colour.utilities import message_box
 
-message_box('"Hellwig and Fairchild (2022)" Colour Appearance Model Computations')
+message_box('Compute "Hellwig and Fairchild (2022)" Colour Appearance Model Correlates')
 
 XYZ = np.array([19.01, 20.00, 21.78])
 XYZ_w = np.array([95.05, 100.00, 108.88])
@@ -13,7 +19,7 @@ L_A = 318.31
 Y_b = 20.0
 surround = colour.VIEWING_CONDITIONS_HELLWIG2022["Average"]
 message_box(
-    f'Converting to the "Hellwig and Fairchild (2022)" colour appearance '
+    f'Convert to the "Hellwig and Fairchild (2022)" colour appearance '
     f"model specification "
     f"using given parameters:\n\n"
     f"\tXYZ: {XYZ}\n"
@@ -32,7 +38,7 @@ C = 0.02576362
 h = 217.06795977
 specification = colour.CAM_Specification_Hellwig2022(J, C, h)
 message_box(
-    f'Converting to "CIE XYZ" tristimulus values using given parameters:\n\n'
+    f'Convert to "CIE XYZ" tristimulus values using given parameters:\n\n'
     f"\tJ: {J}\n"
     f"\tC: {C}\n"
     f"\th: {h}\n"
