@@ -1,9 +1,9 @@
-# !/usr/bin/env python
 """Define the unit tests for the :mod:`colour.geometry.vertices` module."""
 
-import unittest
+from __future__ import annotations
 
 import numpy as np
+import pytest
 
 from colour.constants import TOLERANCE_ABSOLUTE_TESTS
 from colour.geometry import (
@@ -29,13 +29,13 @@ __all__ = [
 ]
 
 
-class TestPrimitiveVerticesQuadMpl(unittest.TestCase):
+class TestPrimitiveVerticesQuadMpl:
     """
     Define :func:`colour.geometry.vertices.primitive_vertices_quad_mpl`
     definition unit tests methods.
     """
 
-    def test_primitive_vertices_quad_mpl(self):
+    def test_primitive_vertices_quad_mpl(self) -> None:
         """
         Test :func:`colour.geometry.vertices.primitive_vertices_quad_mpl`
         definition.
@@ -104,18 +104,16 @@ class TestPrimitiveVerticesQuadMpl(unittest.TestCase):
                 atol=TOLERANCE_ABSOLUTE_TESTS,
             )
 
-        self.assertRaises(
-            ValueError, lambda: primitive_vertices_quad_mpl(axis="Undefined")
-        )
+        pytest.raises(ValueError, lambda: primitive_vertices_quad_mpl(axis="Undefined"))
 
 
-class TestPrimitiveVerticesGridMpl(unittest.TestCase):
+class TestPrimitiveVerticesGridMpl:
     """
     Define :func:`colour.geometry.vertices.primitive_vertices_grid_mpl`
     definition unit tests methods.
     """
 
-    def test_primitive_vertices_grid_mpl(self):
+    def test_primitive_vertices_grid_mpl(self) -> None:
         """
         Test :func:`colour.geometry.vertices.primitive_vertices_grid_mpl`
         definition.
@@ -198,13 +196,13 @@ class TestPrimitiveVerticesGridMpl(unittest.TestCase):
         )
 
 
-class TestPrimitiveVerticesCubeMpl(unittest.TestCase):
+class TestPrimitiveVerticesCubeMpl:
     """
     Define :func:`colour.geometry.vertices.primitive_vertices_cube_mpl`
     definition unit tests methods.
     """
 
-    def test_primitive_vertices_cube_mpl(self):
+    def test_primitive_vertices_cube_mpl(self) -> None:
         """
         Test :func:`colour.geometry.vertices.primitive_vertices_cube_mpl`
         definition.
@@ -592,20 +590,18 @@ class TestPrimitiveVerticesCubeMpl(unittest.TestCase):
         for plane in MAPPING_PLANE_TO_AXIS:
             np.testing.assert_allclose(
                 primitive_vertices_cube_mpl(planes=[plane]),
-                primitive_vertices_cube_mpl(
-                    planes=[MAPPING_PLANE_TO_AXIS[plane]]
-                ),
+                primitive_vertices_cube_mpl(planes=[MAPPING_PLANE_TO_AXIS[plane]]),
                 atol=TOLERANCE_ABSOLUTE_TESTS,
             )
 
 
-class TestPrimitiveVerticesSphere(unittest.TestCase):
+class TestPrimitiveVerticesSphere:
     """
     Define :func:`colour.geometry.vertices.primitive_vertices_sphere`
     definition unit tests methods.
     """
 
-    def test_primitive_vertices_sphere(self):
+    def test_primitive_vertices_sphere(self) -> None:
         """
         Test :func:`colour.geometry.vertices.primitive_vertices_sphere`
         definition.
@@ -998,10 +994,4 @@ class TestPrimitiveVerticesSphere(unittest.TestCase):
                 atol=TOLERANCE_ABSOLUTE_TESTS,
             )
 
-        self.assertRaises(
-            ValueError, lambda: primitive_vertices_quad_mpl(axis="Undefined")
-        )
-
-
-if __name__ == "__main__":
-    unittest.main()
+        pytest.raises(ValueError, lambda: primitive_vertices_quad_mpl(axis="Undefined"))
